@@ -2,17 +2,17 @@
 #
 # SPDX-License-Identifier: GPL-3.0-only
 
+from threading import Thread
+
 import customtkinter
 from customtkinter import CTk, CTkButton, CTkFrame
-from ice_launcher.instances import Instances
-from ice_launcher.news import News
-from ice_launcher.settings import Settings
-from ice_launcher.about import About
-from ice_launcher.accounts import Accounts
 
+from ice_launcher import About, Accounts, Instances, News, Settings, Update
+from ice_launcher.__about__ import __version__
+from ice_launcher.lib import updater
 
-customtkinter.set_appearance_mode("dark")  # Modes: system (default), light, dark
-customtkinter.set_default_color_theme("blue")  # Themes: blue (default), dark-blue, green
+customtkinter.set_appearance_mode("dark")
+customtkinter.set_default_color_theme("blue")
 
 
 class App(CTk):
@@ -100,6 +100,9 @@ class App(CTk):
 
         self.update_main_frame()
 
+        update_checker = Thread(target=self.check_for_updates)
+        update_checker.start()
+
     def on_closing(self, event=0) -> None:
         self.destroy()
 
@@ -112,6 +115,11 @@ class App(CTk):
         self.current_view = view
         self.update_main_frame()
 
+    def check_for_updates(self) -> None:
+        latest_version = updater.check_for_updates(__version__)
+        if latest_version:
+            Update(master=self, latest_version=latest_version)
+
 
 if __name__ == "__main__":
     app: App = App()
